#!/usr/bin/env python
# coding: utf-8

# In[11]:


import tkinter as tk
from PIL import Image, ImageTk
import math

# Layout constants.
MARGIN = 5
WINDOW_WID = 400
WINDOW_HGT = 300

class DrawCirclesApp:
    # Create and manage the tkinter interface.
    def __init__(self):
        # Make the main interface.
        self.window = tk.Tk()
        self.window.title('draw_circles')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry(f'{WINDOW_WID}x{WINDOW_HGT}')

        # Build the menus.
        self.build_menus()

        # Build the rest of the UI here...
        self.canvas = tk.Canvas(self.window, bg='white', cursor='cross',
            borderwidth=2, relief=tk.SUNKEN)
        self.canvas.pack(padx=10, pady=(0, 10),
            side=tk.BOTTOM, fill=tk.BOTH, expand=True)

        # Initially we are not drawing a circle.
        self.start_point = None
        self.end_point = None
        self.current_circle = None

        # Track Button-1 down, Button-1 motion, and Button-1 up.
        self.canvas.bind("<Button-1>", self.mouse_down)
        self.canvas.bind("<B1-Motion>", self.mouse_move)
        self.canvas.bind("<ButtonRelease-1>", self.mouse_up)

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def build_menus(self):
        '''Build the menu bar.'''
        menu_bar = tk.Menu(self.window)
        self.window.config(menu=menu_bar)

        self.build_file_menu(menu_bar)
        self.build_drawing_menu(menu_bar)

    def build_file_menu(self, menu_bar):
        '''Build the File menu.'''
        file_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='File', menu=file_menu)

        # Exit
        self.exit_photo_image = ImageTk.PhotoImage(file='exit.png')
        file_menu.add_command(label='Exit', compound='left',
            command=self.mnu_exit, image=self.exit_photo_image)

    def build_drawing_menu(self, menu_bar):
        '''Build the Drawing menu.'''
        drawing_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='Drawing', menu=drawing_menu)

        # Clear
        drawing_menu.add_command(label='Clear',
            accelerator='Ctrl+C', command=self.mnu_clear)
        self.window.bind('<Control-c>', lambda event: self.mnu_clear())

    def mnu_exit(self):
        self.kill_callback()

    def kill_callback(self):
        self.window.destroy()

    def mnu_clear(self):
        self.canvas.delete(tk.ALL)

    def mouse_down(self, event):
        '''Record the circle's starting point.'''
        self.start_point = (event.x, event.y)

    def mouse_move(self, event):
        # Ignore extraneous events.
        if self.start_point is None: return

        # If there is a current new circle, remove it.
        if self.current_circle is not None:
            self.canvas.delete(self.current_circle)

        # Create the new temporary circle.
        self.end_point = self.get_circle_endpoint(self.start_point, (event.x, event.y))
        self.current_circle = self.canvas.create_oval(
            self.start_point, self.end_point, outline='red')

    def mouse_up(self, event):
        # Ignore extraneous events.
        if self.start_point is None: return

        # If there is a current new circle, remove it.
        if self.current_circle is not None:
            self.canvas.delete(self.current_circle)

        # Create the permanent circle.
        self.end_point = self.get_circle_endpoint(self.start_point, (event.x, event.y))
        self.canvas.create_oval(
            self.start_point, self.end_point, outline='green')

        # We are no longer creating a circle.
        self.start_point = None
        self.end_point = None
        self.current_circle = None

    def get_circle_endpoint(self, start_point, end_point):
        '''Return the other corner for the circle.'''
        # Get the width and height.
        dx = end_point[0] - self.start_point[0]
        dy = end_point[1] - self.start_point[1]

        # Use the larger of the width and height.
        if abs(dx) < abs(dy):
            # Make dx have the size of dy but in the direction of dx.
            dx = math.copysign(dy, dx)
        else:
            # Make dy have the size of dx but in the direction of dy.
            dy = math.copysign(dx, dy)
        return (start_point[0] + dx, start_point[1] + dy)


# In[12]:


DrawCirclesApp()
print('Done')


# In[ ]:




